/// <reference types="vitest" />

import path from 'node:path'
import { defineConfig } from 'vite'
import Vue from '@vitejs/plugin-vue'
import WindiCss from 'vite-plugin-windicss'
import Pages from 'vite-plugin-pages'
import Components from 'unplugin-vue-components/vite'
import { ElementPlusResolver } from 'unplugin-vue-components/resolvers'
import AutoImport from 'unplugin-auto-import/vite'
import VueMacros from 'unplugin-vue-macros/vite'
import Icons from 'unplugin-icons/vite'
import IconsResolver from 'unplugin-icons/resolver'
import topLevelAwait from 'vite-plugin-top-level-await'
import ConditionalCompile from './plugins/vite-plugin-conditional-compile'

export default defineConfig(({ command }) => {
  const cfg = {
    base: '',
    server: {
      open: true,
      port: 8081,
      host: '0.0.0.0',
    },
    resolve: {
      alias: {
        '~/': `${path.resolve(__dirname, 'src')}/`,
        '@': `${path.resolve(__dirname, 'src')}`,

      },
    },
    plugins: [
      ConditionalCompile(),
      topLevelAwait({
        // The export name of top-level await promise for each chunk module
        promiseExportName: '__tla',
        // The function to generate import names of top-level await promise in each chunk module
        promiseImportName: i => `__tla_${i}`,
      }),
      VueMacros({
        plugins: {
          vue: Vue({
            reactivityTransform: true,
          }),
        },
      }),
      WindiCss(),
      // https://github.com/hannoeru/vite-plugin-pages
      Pages({ extensions: ['vue'] }),

      // https://github.com/antfu/unplugin-auto-import
      AutoImport({
        imports: [
          'vue',
          'vue/macros',
          'vue-router',
          '@vueuse/core',
        ],
        dts: true,
        dirs: [
          './src/composables',
        ],
        vueTemplate: true,
        resolvers: [ElementPlusResolver()],
      }),

      // https://github.com/antfu/vite-plugin-components
      Components({
        dts: true,
        resolvers: [ElementPlusResolver(), IconsResolver()],
      }),
      Icons({
        compiler: 'vue3',
        autoInstall: true,
      }),
      // https://github.com/antfu/unocss
      // see unocss.config.ts for config
    ],

    // https://github.com/vitest-dev/vitest
    test: {
      environment: 'jsdom',
    },
  }
  if (command === 'build') {
    cfg.base = '/webapps/page/liankao/'
    return cfg
  }
  else {
    return cfg
  }
})
